@@ -110,8 +110,9 @@ class ErrorMessage(Enum):
     TestDescriptionNotUnique = 'test description must be unique'
     ParameterNotValid = 'parameter are not valid'
     BinTableNotfilled = 'make sure to fill bin table'
-    UserNameMissing = 'user naming is missing'
-    UserNameUsed = 'user defined name is already used'
+    BinTableConstraintUnfulfilled = 'make sure that bin number and bin name are unique'
+    UserNameMissing = 'name is missing'
+    UserNameUsed = 'defined name is already used'
 
     def __call__(self):
         return self.value
